@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2006 OpenedHand Ltd.
+ * Copyright (C) 2006, 2007 OpenedHand Ltd.
  *
  * Author: Jorn Baayen <jorn@openedhand.com>
  *
@@ -22,13 +22,20 @@
 #ifndef __GUPNP_SERVICE_PROXY_PRIVATE_H__
 #define __GUPNP_SERVICE_PROXY_PRIVATE_H__
 
+#include <libxml/tree.h>
+
+#include "gupnp-context.h"
 #include "gupnp-service-proxy.h"
 
 GUPnPServiceProxy *
-_gupnp_service_proxy_new_from_element (GUPnPContext  *context,
-                                       xmlNode       *element,
-                                       const char    *location,
-                                       const char    *udn,
-                                       const xmlChar *url_base);
+_gupnp_service_proxy_new              (GUPnPContext      *context,
+                                       xmlNode           *element,
+                                       const char        *udn,
+                                       const char        *service_type,
+                                       const char        *location,
+                                       const SoupUri     *url_base);
+
+void
+_gupnp_service_proxy_unsubscribe_sync (GUPnPServiceProxy *proxy);
 
 #endif /* __GUPNP_SERVICE_PROXY_PRIVATE_H__ */
